@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 from argparse import ArgumentParser
 from pathlib import Path
+from shlex import quote
 from subprocess import check_call, SubprocessError
 import sys
 from jinja2 import Environment, FileSystemLoader
@@ -62,6 +63,18 @@ def detect_package(location: Path) -> str:
         return detect_package(location.parent) + "/" + location.name
 
 
+def iter_enums(swagger: dict):
+    for name, definition in swagger.get('definitions', {}).items():
+        if 'enum' in definition:
+            yield name, definition
+
+
+def cast(value, definition: dict) -> str:
+    if definition.get('type') == 'string':
+        return f'"{value}"'  # TODO: fix to proper escaping
+    return value
+
+
 def main():
     parser = ArgumentParser(description='Zombie swagger 2.0')
     parser.add_argument('--swagger', '-s', type=Path, default=(Path.cwd() / "swagger.yaml"),
@@ -77,11 +90,14 @@ def main():
     env.filters['map_type'] = map_type
     env.filters['label'] = lambda x: x[0].upper() + x[1:]
     env.filters['path'] = path
+    env.filters['cast'] = cast
     env.filters['secured'] = lambda x: len(x.get('security', [])) > 0
     env.filters['sec_def'] = lambda x: swagger['securityDefinitions'][x]
     env.filters['has_payload'] = lambda x: any(param for param in x.get('parameters', []) if param['in'] == 'body')
     swagger = safe_load(args.swagger.read_text())
 
+    enums = tuple(iter_enums(swagger))
+
     base_file = args.output / "interfaces.go"
     client_file = args.output / "client" / "client.go"
     server_file = args.output / "server" / "server.go"
@@ -97,6 +113,7 @@ def main():
         package=package,
         credential_type=args.credential,
         api_package=api_package,
+        enums=enums,
         has_security=len(
             swagger.get('securityDefinitions', {})) > 0))
 
@@ -104,6 +121,7 @@ def main():
         header=f"// Code generated by simple-swagger {' '.join(sys.argv[1:])} DO NOT EDIT.",
         swagger=swagger,
         package="server",
+        enums=enums,
         credential_type=args.credential,
         api_package=api_package,
         has_security=len(
@@ -113,6 +131,7 @@ def main():
         header=f"// Code generated by simple-swagger {' '.join(sys.argv[1:])} DO NOT EDIT.",
         swagger=swagger,
         package="client",
+        enums=enums,
         credential_type=args.credential,
         api_package=api_package,
         has_security=len(
